## How to contribute to skpro

#### **Did you find a bug?**

* **Ensure the bug was not already reported** by searching on GitHub under [Issues](https://github.com/alan-turing-institute/skpro/issues).

* If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/alan-turing-institute/skpro/issues/new). Be sure to include a **title and clear description**, as much relevant information as possible, and a **code sample** or an **executable test case** demonstrating the expected behavior that is not occurring.

* Please follow the further discussion in case more information is needed or questions arise.

#### **Did you write a patch that fixes a bug?**

* Open a new GitHub pull request with the patch.

* Ensure the PR description clearly describes the problem and solution. Include the relevant issue number if applicable.

#### **Do you intend to add a new feature or change an existing one?**

* Suggest your change in an issue and offer to implement the feature. 

* Wait for positive feedback in order to avoid double work (maybe your idea is already in development).

* Implement and send a PR

#### **Do you have questions about the source code?**

* Ask any question about how to use skpro using the forum.

#### **Do you want to contribute to the skpro documentation?**

* Please send PR that propose changes to the docs directory
 
skpro is a team effort. We encourage you to pitch in and join us!

Thanks! :heart: :heart: :heart:

skpro Team
